pygeodesy.geod3solve

Package pygeodesy :: Module geod3solve |
[frames] | no frames]

# Module geod3solve

Wrapper to invoke Karney's Geod3Solve utility as a `triaxial` geodesic, but intended mainly for testing purposes.

Set env variable `PYGEODESY_GEOD3SOLVE` to the (fully qualified) path of the `Geod3Solve` executable or use property Geodesic3Solve.Geod3Solve.

Version: 26.02.12

Classes
| Geodesic3Error Error raised for issues in geod3solve.
| Geod3Solve8Tuple 8-Tuple `(bet1, omg1, alp1, bet2, omg2, alp2, s12, a12)` with `ellipsoidal` latitudes `bet1` and `bet2`, `ellipsoidal` longitudes `omg1` and `omg2`, forward azimuths `alp1` and `alp2` in bearings from North, distance `s12` in `meter`, conventionally and approximate arc length `a12` in degrees, see Geod3Solve.
| _Geodesic3SolveBase (INTERNAL) Base class for Geodesic3Solve and GeodesicLine3Solve.
| Geodesic3Solve Wrapper to invoke Karney's Geod3Solve as a `triaxial` version of Karney's Python class Geodesic.
| GeodesicLine3Solve Wrapper to invoke Karney's Geod3Solve as a `triaxial` version of Karney's Python class GeodesicLine.

Variables
| __all__ = `_ALL_LAZY.geod3solve`